colorspace.py — Blessed 1.17.7 documentation

# colorspace.py

Color reference data.

References,

- https://github.com/freedesktop/xorg-rgb/blob/master/rgb.txt

- https://github.com/ThomasDickey/xterm-snapshots/blob/master/256colres.h

- https://github.com/ThomasDickey/xterm-snapshots/blob/master/XTerm-col.ad

- https://en.wikipedia.org/wiki/ANSI_escape_code#Colors

- https://gist.github.com/XVilka/8346728

- https://devblogs.microsoft.com/commandline/24-bit-color-in-the-windows-console/

- http://jdebp.eu/Softwares/nosh/guide/TerminalCapabilities.html

class `RGBColor`

  Named tuple for an RGB color definition.

  Create new instance of RGBColor(red, green, blue)

`X11_COLORNAMES_TO_RGB` = {'aliceblue': RGBColor(red=240, green=248, blue=255), 'antiquewhite': RGBColor(red=250, green=235, blue=215), 'antiquewhite1': RGBColor(red=255, green=239, blue=219), 'antiquewhite2': RGBColor(red=238, green=223, blue=204), 'antiquewhite3': RGBColor(red=205, green=192, blue=176), 'antiquewhite4': RGBColor(red=139, green=131, blue=120), 'aqua': RGBColor(red=0, green=255, blue=255), 'aquamarine': RGBColor(red=127, green=255, blue=212), 'aquamarine1': RGBColor(red=127, green=255, blue=212), 'aquamarine2': RGBColor(red=118, green=238, blue=198), 'aquamarine3': RGBColor(red=102, green=205, blue=170), 'aquamarine4': RGBColor(red=69, green=139, blue=116), 'azure': RGBColor(red=240, green=255, blue=255), 'azure1': RGBColor(red=240, green=255, blue=255), 'azure2': RGBColor(red=224, green=238, blue=238), 'azure3': RGBColor(red=193, green=205, blue=205), 'azure4': RGBColor(red=131, green=139, blue=139), 'beige': RGBColor(red=245, green=245, blue=220), 'bisque': RGBColor(red=255, green=228, blue=196), 'bisque1': RGBColor(red=255, green=228, blue=196), 'bisque2': RGBColor(red=238, green=213, blue=183), 'bisque3': RGBColor(red=205, green=183, blue=158), 'bisque4': RGBColor(red=139, green=125, blue=107), 'black': RGBColor(red=0, green=0, blue=0), 'blanchedalmond': RGBColor(red=255, green=235, blue=205), 'blue': RGBColor(red=0, green=0, blue=255), 'blue1': RGBColor(red=0, green=0, blue=255), 'blue2': RGBColor(red=0, green=0, blue=238), 'blue3': RGBColor(red=0, green=0, blue=205), 'blue4': RGBColor(red=0, green=0, blue=139), 'blueviolet': RGBColor(red=138, green=43, blue=226), 'brown': RGBColor(red=165, green=42, blue=42), 'brown1': RGBColor(red=255, green=64, blue=64), 'brown2': RGBColor(red=238, green=59, blue=59), 'brown3': RGBColor(red=205, green=51, blue=51), 'brown4': RGBColor(red=139, green=35, blue=35), 'burlywood': RGBColor(red=222, green=184, blue=135), 'burlywood1': RGBColor(red=255, green=211, blue=155), 'burlywood2': RGBColor(red=238, green=197, blue=145), 'burlywood3': RGBColor(red=205, green=170, blue=125), 'burlywood4': RGBColor(red=139, green=115, blue=85), 'cadetblue': RGBColor(red=95, green=158, blue=160), 'cadetblue1': RGBColor(red=152, green=245, blue=255), 'cadetblue2': RGBColor(red=142, green=229, blue=238), 'cadetblue3': RGBColor(red=122, green=197, blue=205), 'cadetblue4': RGBColor(red=83, green=134, blue=139), 'chartreuse': RGBColor(red=127, green=255, blue=0), 'chartreuse1': RGBColor(red=127, green=255, blue=0), 'chartreuse2': RGBColor(red=118, green=238, blue=0), 'chartreuse3': RGBColor(red=102, green=205, blue=0), 'chartreuse4': RGBColor(red=69, green=139, blue=0), 'chocolate': RGBColor(red=210, green=105, blue=30), 'chocolate1': RGBColor(red=255, green=127, blue=36), 'chocolate2': RGBColor(red=238, green=118, blue=33), 'chocolate3': RGBColor(red=205, green=102, blue=29), 'chocolate4': RGBColor(red=139, green=69, blue=19), 'coral': RGBColor(red=255, green=127, blue=80), 'coral1': RGBColor(red=255, green=114, blue=86), 'coral2': RGBColor(red=238, green=106, blue=80), 'coral3': RGBColor(red=205, green=91, blue=69), 'coral4': RGBColor(red=139, green=62, blue=47), 'cornflowerblue': RGBColor(red=100, green=149, blue=237), 'cornsilk': RGBColor(red=255, green=248, blue=220), 'cornsilk1': RGBColor(red=255, green=248, blue=220), 'cornsilk2': RGBColor(red=238, green=232, blue=205), 'cornsilk3': RGBColor(red=205, green=200, blue=177), 'cornsilk4': RGBColor(red=139, green=136, blue=120), 'crimson': RGBColor(red=220, green=20, blue=60), 'cyan': RGBColor(red=0, green=255, blue=255), 'cyan1': RGBColor(red=0, green=255, blue=255), 'cyan2': RGBColor(red=0, green=238, blue=238), 'cyan3': RGBColor(red=0, green=205, blue=205), 'cyan4': RGBColor(red=0, green=139, blue=139), 'darkblue': RGBColor(red=0, green=0, blue=139), 'darkcyan': RGBColor(red=0, green=139, blue=139), 'darkgoldenrod': RGBColor(red=184, green=134, blue=11), 'darkgoldenrod1': RGBColor(red=255, green=185, blue=15), 'darkgoldenrod2': RGBColor(red=238, green=173, blue=14), 'darkgoldenrod3': RGBColor(red=205, green=149, blue=12), 'darkgoldenrod4': RGBColor(red=139, green=101, blue=8), 'darkgray': RGBColor(red=169, green=169, blue=169), 'darkgreen': RGBColor(red=0, green=100, blue=0), 'darkgrey': RGBColor(red=169, green=169, blue=169), 'darkkhaki': RGBColor(red=189, green=183, blue=107), 'darkmagenta': RGBColor(red=139, green=0, blue=139), 'darkolivegreen': RGBColor(red=85, green=107, blue=47), 'darkolivegreen1': RGBColor(red=202, green=255, blue=112), 'darkolivegreen2': RGBColor(red=188, green=238, blue=104), 'darkolivegreen3': RGBColor(red=162, green=205, blue=90), 'darkolivegreen4': RGBColor(red=110, green=139, blue=61), 'darkorange': RGBColor(red=255, green=140, blue=0), 'darkorange1': RGBColor(red=255, green=127, blue=0), 'darkorange2': RGBColor(red=238, green=118, blue=0), 'darkorange3': RGBColor(red=205, green=102, blue=0), 'darkorange4': RGBColor(red=139, green=69, blue=0), 'darkorchid': RGBColor(red=153, green=50, blue=204), 'darkorchid1': RGBColor(red=191, green=62, blue=255), 'darkorchid2': RGBColor(red=178, green=58, blue=238), 'darkorchid3': RGBColor(red=154, green=50, blue=205), 'darkorchid4': RGBColor(red=104, green=34, blue=139), 'darkred': RGBColor(red=139, green=0, blue=0), 'darksalmon': RGBColor(red=233, green=150, blue=122), 'darkseagreen': RGBColor(red=143, green=188, blue=143), 'darkseagreen1': RGBColor(red=193, green=255, blue=193), 'darkseagreen2': RGBColor(red=180, green=238, blue=180), 'darkseagreen3': RGBColor(red=155, green=205, blue=155), 'darkseagreen4': RGBColor(red=105, green=139, blue=105), 'darkslateblue': RGBColor(red=72, green=61, blue=139), 'darkslategray': RGBColor(red=47, green=79, blue=79), 'darkslategray1': RGBColor(red=151, green=255, blue=255), 'darkslategray2': RGBColor(red=141, green=238, blue=238), 'darkslategray3': RGBColor(red=121, green=205, blue=205), 'darkslategray4': RGBColor(red=82, green=139, blue=139), 'darkslategrey': RGBColor(red=47, green=79, blue=79), 'darkturquoise': RGBColor(red=0, green=206, blue=209), 'darkviolet': RGBColor(red=148, green=0, blue=211), 'deeppink': RGBColor(red=255, green=20, blue=147), 'deeppink1': RGBColor(red=255, green=20, blue=147), 'deeppink2': RGBColor(red=238, green=18, blue=137), 'deeppink3': RGBColor(red=205, green=16, blue=118), 'deeppink4': RGBColor(red=139, green=10, blue=80), 'deepskyblue': RGBColor(red=0, green=191, blue=255), 'deepskyblue1': RGBColor(red=0, green=191, blue=255), 'deepskyblue2': RGBColor(red=0, green=178, blue=238), 'deepskyblue3': RGBColor(red=0, green=154, blue=205), 'deepskyblue4': RGBColor(red=0, green=104, blue=139), 'dimgray': RGBColor(red=105, green=105, blue=105), 'dimgrey': RGBColor(red=105, green=105, blue=105), 'dodgerblue': RGBColor(red=30, green=144, blue=255), 'dodgerblue1': RGBColor(red=30, green=144, blue=255), 'dodgerblue2': RGBColor(red=28, green=134, blue=238), 'dodgerblue3': RGBColor(red=24, green=116, blue=205), 'dodgerblue4': RGBColor(red=16, green=78, blue=139), 'firebrick': RGBColor(red=178, green=34, blue=34), 'firebrick1': RGBColor(red=255, green=48, blue=48), 'firebrick2': RGBColor(red=238, green=44, blue=44), 'firebrick3': RGBColor(red=205, green=38, blue=38), 'firebrick4': RGBColor(red=139, green=26, blue=26), 'floralwhite': RGBColor(red=255, green=250, blue=240), 'forestgreen': RGBColor(red=34, green=139, blue=34), 'fuchsia': RGBColor(red=255, green=0, blue=255), 'gainsboro': RGBColor(red=220, green=220, blue=220), 'ghostwhite': RGBColor(red=248, green=248, blue=255), 'gold': RGBColor(red=255, green=215, blue=0), 'gold1': RGBColor(red=255, green=215, blue=0), 'gold2': RGBColor(red=238, green=201, blue=0), 'gold3': RGBColor(red=205, green=173, blue=0), 'gold4': RGBColor(red=139, green=117, blue=0), 'goldenrod': RGBColor(red=218, green=165, blue=32), 'goldenrod1': RGBColor(red=255, green=193, blue=37), 'goldenrod2': RGBColor(red=238, green=180, blue=34), 'goldenrod3': RGBColor(red=205, green=155, blue=29), 'goldenrod4': RGBColor(red=139, green=105, blue=20), 'gray': RGBColor(red=190, green=190, blue=190), 'gray0': RGBColor(red=0, green=0, blue=0), 'gray1': RGBColor(red=3, green=3, blue=3), 'gray10': RGBColor(red=26, green=26, blue=26), 'gray100': RGBColor(red=255, green=255, blue=255), 'gray11': RGBColor(red=28, green=28, blue=28), 'gray12': RGBColor(red=31, green=31, blue=31), 'gray13': RGBColor(red=33, green=33, blue=33), 'gray14': RGBColor(red=36, green=36, blue=36), 'gray15': RGBColor(red=38, green=38, blue=38), 'gray16': RGBColor(red=41, green=41, blue=41), 'gray17': RGBColor(red=43, green=43, blue=43), 'gray18': RGBColor(red=46, green=46, blue=46), 'gray19': RGBColor(red=48, green=48, blue=48), 'gray2': RGBColor(red=5, green=5, blue=5), 'gray20': RGBColor(red=51, green=51, blue=51), 'gray21': RGBColor(red=54, green=54, blue=54), 'gray22': RGBColor(red=56, green=56, blue=56), 'gray23': RGBColor(red=59, green=59, blue=59), 'gray24': RGBColor(red=61, green=61, blue=61), 'gray25': RGBColor(red=64, green=64, blue=64), 'gray26': RGBColor(red=66, green=66, blue=66), 'gray27': RGBColor(red=69, green=69, blue=69), 'gray28': RGBColor(red=71, green=71, blue=71), 'gray29': RGBColor(red=74, green=74, blue=74), 'gray3': RGBColor(red=8, green=8, blue=8), 'gray30': RGBColor(red=77, green=77, blue=77), 'gray31': RGBColor(red=79, green=79, blue=79), 'gray32': RGBColor(red=82, green=82, blue=82), 'gray33': RGBColor(red=84, green=84, blue=84), 'gray34': RGBColor(red=87, green=87, blue=87), 'gray35': RGBColor(red=89, green=89, blue=89), 'gray36': RGBColor(red=92, green=92, blue=92), 'gray37': RGBColor(red=94, green=94, blue=94), 'gray38': RGBColor(red=97, green=97, blue=97), 'gray39': RGBColor(red=99, green=99, blue=99), 'gray4': RGBColor(red=10, green=10, blue=10), 'gray40': RGBColor(red=102, green=102, blue=102), 'gray41': RGBColor(red=105, green=105, blue=105), 'gray42': RGBColor(red=107, green=107, blue=107), 'gray43': RGBColor(red=110, green=110, blue=110), 'gray44': RGBColor(red=112, green=112, blue=112), 'gray45': RGBColor(red=115, green=115, blue=115), 'gray46': RGBColor(red=117, green=117, blue=117), 'gray47': RGBColor(red=120, green=120, blue=120), 'gray48': RGBColor(red=122, green=122, blue=122), 'gray49': RGBColor(red=125, green=125, blue=125), 'gray5': RGBColor(red=13, green=13, blue=13), 'gray50': RGBColor(red=127, green=127, blue=127), 'gray51': RGBColor(red=130, green=130, blue=130), 'gray52': RGBColor(red=133, green=133, blue=133), 'gray53': RGBColor(red=135, green=135, blue=135), 'gray54': RGBColor(red=138, green=138, blue=138), 'gray55': RGBColor(red=140, green=140, blue=140), 'gray56': RGBColor(red=143, green=143, blue=143), 'gray57': RGBColor(red=145, green=145, blue=145), 'gray58': RGBColor(red=148, green=148, blue=148), 'gray59': RGBColor(red=150, green=150, blue=150), 'gray6': RGBColor(red=15, green=15, blue=15), 'gray60': RGBColor(red=153, green=153, blue=153), 'gray61': RGBColor(red=156, green=156, blue=156), 'gray62': RGBColor(red=158, green=158, blue=158), 'gray63': RGBColor(red=161, green=161, blue=161), 'gray64': RGBColor(red=163, green=163, blue=163), 'gray65': RGBColor(red=166, green=166, blue=166), 'gray66': RGBColor(red=168, green=168, blue=168), 'gray67': RGBColor(red=171, green=171, blue=171), 'gray68': RGBColor(red=173, green=173, blue=173), 'gray69': RGBColor(red=176, green=176, blue=176), 'gray7': RGBColor(red=18, green=18, blue=18), 'gray70': RGBColor(red=179, green=179, blue=179), 'gray71': RGBColor(red=181, green=181, blue=181), 'gray72': RGBColor(red=184, green=184, blue=184), 'gray73': RGBColor(red=186, green=186, blue=186), 'gray74': RGBColor(red=189, green=189, blue=189), 'gray75': RGBColor(red=191, green=191, blue=191), 'gray76': RGBColor(red=194, green=194, blue=194), 'gray77': RGBColor(red=196, green=196, blue=196), 'gray78': RGBColor(red=199, green=199, blue=199), 'gray79': RGBColor(red=201, green=201, blue=201), 'gray8': RGBColor(red=20, green=20, blue=20), 'gray80': RGBColor(red=204, green=204, blue=204), 'gray81': RGBColor(red=207, green=207, blue=207), 'gray82': RGBColor(red=209, green=209, blue=209), 'gray83': RGBColor(red=212, green=212, blue=212), 'gray84': RGBColor(red=214, green=214, blue=214), 'gray85': RGBColor(red=217, green=217, blue=217), 'gray86': RGBColor(red=219, green=219, blue=219), 'gray87': RGBColor(red=222, green=222, blue=222), 'gray88': RGBColor(red=224, green=224, blue=224), 'gray89': RGBColor(red=227, green=227, blue=227), 'gray9': RGBColor(red=23, green=23, blue=23), 'gray90': RGBColor(red=229, green=229, blue=229), 'gray91': RGBColor(red=232, green=232, blue=232), 'gray92': RGBColor(red=235, green=235, blue=235), 'gray93': RGBColor(red=237, green=237, blue=237), 'gray94': RGBColor(red=240, green=240, blue=240), 'gray95': RGBColor(red=242, green=242, blue=242), 'gray96': RGBColor(red=245, green=245, blue=245), 'gray97': RGBColor(red=247, green=247, blue=247), 'gray98': RGBColor(red=250, green=250, blue=250), 'gray99': RGBColor(red=252, green=252, blue=252), 'green': RGBColor(red=0, green=255, blue=0), 'green1': RGBColor(red=0, green=255, blue=0), 'green2': RGBColor(red=0, green=238, blue=0), 'green3': RGBColor(red=0, green=205, blue=0), 'green4': RGBColor(red=0, green=139, blue=0), 'greenyellow': RGBColor(red=173, green=255, blue=47), 'grey': RGBColor(red=190, green=190, blue=190), 'grey0': RGBColor(red=0, green=0, blue=0), 'grey1': RGBColor(red=3, green=3, blue=3), 'grey10': RGBColor(red=26, green=26, blue=26), 'grey100': RGBColor(red=255, green=255, blue=255), 'grey11': RGBColor(red=28, green=28, blue=28), 'grey12': RGBColor(red=31, green=31, blue=31), 'grey13': RGBColor(red=33, green=33, blue=33), 'grey14': RGBColor(red=36, green=36, blue=36), 'grey15': RGBColor(red=38, green=38, blue=38), 'grey16': RGBColor(red=41, green=41, blue=41), 'grey17': RGBColor(red=43, green=43, blue=43), 'grey18': RGBColor(red=46, green=46, blue=46), 'grey19': RGBColor(red=48, green=48, blue=48), 'grey2': RGBColor(red=5, green=5, blue=5), 'grey20': RGBColor(red=51, green=51, blue=51), 'grey21': RGBColor(red=54, green=54, blue=54), 'grey22': RGBColor(red=56, green=56, blue=56), 'grey23': RGBColor(red=59, green=59, blue=59), 'grey24': RGBColor(red=61, green=61, blue=61), 'grey25': RGBColor(red=64, green=64, blue=64), 'grey26': RGBColor(red=66, green=66, blue=66), 'grey27': RGBColor(red=69, green=69, blue=69), 'grey28': RGBColor(red=71, green=71, blue=71), 'grey29': RGBColor(red=74, green=74, blue=74), 'grey3': RGBColor(red=8, green=8, blue=8), 'grey30': RGBColor(red=77, green=77, blue=77), 'grey31': RGBColor(red=79, green=79, blue=79), 'grey32': RGBColor(red=82, green=82, blue=82), 'grey33': RGBColor(red=84, green=84, blue=84), 'grey34': RGBColor(red=87, green=87, blue=87), 'grey35': RGBColor(red=89, green=89, blue=89), 'grey36': RGBColor(red=92, green=92, blue=92), 'grey37': RGBColor(red=94, green=94, blue=94), 'grey38': RGBColor(red=97, green=97, blue=97), 'grey39': RGBColor(red=99, green=99, blue=99), 'grey4': RGBColor(red=10, green=10, blue=10), 'grey40': RGBColor(red=102, green=102, blue=102), 'grey41': RGBColor(red=105, green=105, blue=105), 'grey42': RGBColor(red=107, green=107, blue=107), 'grey43': RGBColor(red=110, green=110, blue=110), 'grey44': RGBColor(red=112, green=112, blue=112), 'grey45': RGBColor(red=115, green=115, blue=115), 'grey46': RGBColor(red=117, green=117, blue=117), 'grey47': RGBColor(red=120, green=120, blue=120), 'grey48': RGBColor(red=122, green=122, blue=122), 'grey49': RGBColor(red=125, green=125, blue=125), 'grey5': RGBColor(red=13, green=13, blue=13), 'grey50': RGBColor(red=127, green=127, blue=127), 'grey51': RGBColor(red=130, green=130, blue=130), 'grey52': RGBColor(red=133, green=133, blue=133), 'grey53': RGBColor(red=135, green=135, blue=135), 'grey54': RGBColor(red=138, green=138, blue=138), 'grey55': RGBColor(red=140, green=140, blue=140), 'grey56': RGBColor(red=143, green=143, blue=143), 'grey57': RGBColor(red=145, green=145, blue=145), 'grey58': RGBColor(red=148, green=148, blue=148), 'grey59': RGBColor(red=150, green=150, blue=150), 'grey6': RGBColor(red=15, green=15, blue=15), 'grey60': RGBColor(red=153, green=153, blue=153), 'grey61': RGBColor(red=156, green=156, blue=156), 'grey62': RGBColor(red=158, green=158, blue=158), 'grey63': RGBColor(red=161, green=161, blue=161), 'grey64': RGBColor(red=163, green=163, blue=163), 'grey65': RGBColor(red=166, green=166, blue=166), 'grey66': RGBColor(red=168, green=168, blue=168), 'grey67': RGBColor(red=171, green=171, blue=171), 'grey68': RGBColor(red=173, green=173, blue=173), 'grey69': RGBColor(red=176, green=176, blue=176), 'grey7': RGBColor(red=18, green=18, blue=18), 'grey70': RGBColor(red=179, green=179, blue=179), 'grey71': RGBColor(red=181, green=181, blue=181), 'grey72': RGBColor(red=184, green=184, blue=184), 'grey73': RGBColor(red=186, green=186, blue=186), 'grey74': RGBColor(red=189, green=189, blue=189), 'grey75': RGBColor(red=191, green=191, blue=191), 'grey76': RGBColor(red=194, green=194, blue=194), 'grey77': RGBColor(red=196, green=196, blue=196), 'grey78': RGBColor(red=199, green=199, blue=199), 'grey79': RGBColor(red=201, green=201, blue=201), 'grey8': RGBColor(red=20, green=20, blue=20), 'grey80': RGBColor(red=204, green=204, blue=204), 'grey81': RGBColor(red=207, green=207, blue=207), 'grey82': RGBColor(red=209, green=209, blue=209), 'grey83': RGBColor(red=212, green=212, blue=212), 'grey84': RGBColor(red=214, green=214, blue=214), 'grey85': RGBColor(red=217, green=217, blue=217), 'grey86': RGBColor(red=219, green=219, blue=219), 'grey87': RGBColor(red=222, green=222, blue=222), 'grey88': RGBColor(red=224, green=224, blue=224), 'grey89': RGBColor(red=227, green=227, blue=227), 'grey9': RGBColor(red=23, green=23, blue=23), 'grey90': RGBColor(red=229, green=229, blue=229), 'grey91': RGBColor(red=232, green=232, blue=232), 'grey92': RGBColor(red=235, green=235, blue=235), 'grey93': RGBColor(red=237, green=237, blue=237), 'grey94': RGBColor(red=240, green=240, blue=240), 'grey95': RGBColor(red=242, green=242, blue=242), 'grey96': RGBColor(red=245, green=245, blue=245), 'grey97': RGBColor(red=247, green=247, blue=247), 'grey98': RGBColor(red=250, green=250, blue=250), 'grey99': RGBColor(red=252, green=252, blue=252), 'honeydew': RGBColor(red=240, green=255, blue=240), 'honeydew1': RGBColor(red=240, green=255, blue=240), 'honeydew2': RGBColor(red=224, green=238, blue=224), 'honeydew3': RGBColor(red=193, green=205, blue=193), 'honeydew4': RGBColor(red=131, green=139, blue=131), 'hotpink': RGBColor(red=255, green=105, blue=180), 'hotpink1': RGBColor(red=255, green=110, blue=180), 'hotpink2': RGBColor(red=238, green=106, blue=167), 'hotpink3': RGBColor(red=205, green=96, blue=144), 'hotpink4': RGBColor(red=139, green=58, blue=98), 'indianred': RGBColor(red=205, green=92, blue=92), 'indianred1': RGBColor(red=255, green=106, blue=106), 'indianred2': RGBColor(red=238, green=99, blue=99), 'indianred3': RGBColor(red=205, green=85, blue=85), 'indianred4': RGBColor(red=139, green=58, blue=58), 'indigo': RGBColor(red=75, green=0, blue=130), 'ivory': RGBColor(red=255, green=255, blue=240), 'ivory1': RGBColor(red=255, green=255, blue=240), 'ivory2': RGBColor(red=238, green=238, blue=224), 'ivory3': RGBColor(red=205, green=205, blue=193), 'ivory4': RGBColor(red=139, green=139, blue=131), 'khaki': RGBColor(red=240, green=230, blue=140), 'khaki1': RGBColor(red=255, green=246, blue=143), 'khaki2': RGBColor(red=238, green=230, blue=133), 'khaki3': RGBColor(red=205, green=198, blue=115), 'khaki4': RGBColor(red=139, green=134, blue=78), 'lavender': RGBColor(red=230, green=230, blue=250), 'lavenderblush': RGBColor(red=255, green=240, blue=245), 'lavenderblush1': RGBColor(red=255, green=240, blue=245), 'lavenderblush2': RGBColor(red=238, green=224, blue=229), 'lavenderblush3': RGBColor(red=205, green=193, blue=197), 'lavenderblush4': RGBColor(red=139, green=131, blue=134), 'lawngreen': RGBColor(red=124, green=252, blue=0), 'lemonchiffon': RGBColor(red=255, green=250, blue=205), 'lemonchiffon1': RGBColor(red=255, green=250, blue=205), 'lemonchiffon2': RGBColor(red=238, green=233, blue=191), 'lemonchiffon3': RGBColor(red=205, green=201, blue=165), 'lemonchiffon4': RGBColor(red=139, green=137, blue=112), 'lightblue': RGBColor(red=173, green=216, blue=230), 'lightblue1': RGBColor(red=191, green=239, blue=255), 'lightblue2': RGBColor(red=178, green=223, blue=238), 'lightblue3': RGBColor(red=154, green=192, blue=205), 'lightblue4': RGBColor(red=104, green=131, blue=139), 'lightcoral': RGBColor(red=240, green=128, blue=128), 'lightcyan': RGBColor(red=224, green=255, blue=255), 'lightcyan1': RGBColor(red=224, green=255, blue=255), 'lightcyan2': RGBColor(red=209, green=238, blue=238), 'lightcyan3': RGBColor(red=180, green=205, blue=205), 'lightcyan4': RGBColor(red=122, green=139, blue=139), 'lightgoldenrod': RGBColor(red=238, green=221, blue=130), 'lightgoldenrod1': RGBColor(red=255, green=236, blue=139), 'lightgoldenrod2': RGBColor(red=238, green=220, blue=130), 'lightgoldenrod3': RGBColor(red=205, green=190, blue=112), 'lightgoldenrod4': RGBColor(red=139, green=129, blue=76), 'lightgoldenrodyellow': RGBColor(red=250, green=250, blue=210), 'lightgray': RGBColor(red=211, green=211, blue=211), 'lightgreen': RGBColor(red=144, green=238, blue=144), 'lightgrey': RGBColor(red=211, green=211, blue=211), 'lightpink': RGBColor(red=255, green=182, blue=193), 'lightpink1': RGBColor(red=255, green=174, blue=185), 'lightpink2': RGBColor(red=238, green=162, blue=173), 'lightpink3': RGBColor(red=205, green=140, blue=149), 'lightpink4': RGBColor(red=139, green=95, blue=101), 'lightsalmon': RGBColor(red=255, green=160, blue=122), 'lightsalmon1': RGBColor(red=255, green=160, blue=122), 'lightsalmon2': RGBColor(red=238, green=149, blue=114), 'lightsalmon3': RGBColor(red=205, green=129, blue=98), 'lightsalmon4': RGBColor(red=139, green=87, blue=66), 'lightseagreen': RGBColor(red=32, green=178, blue=170), 'lightskyblue': RGBColor(red=135, green=206, blue=250), 'lightskyblue1': RGBColor(red=176, green=226, blue=255), 'lightskyblue2': RGBColor(red=164, green=211, blue=238), 'lightskyblue3': RGBColor(red=141, green=182, blue=205), 'lightskyblue4': RGBColor(red=96, green=123, blue=139), 'lightslateblue': RGBColor(red=132, green=112, blue=255), 'lightslategray': RGBColor(red=119, green=136, blue=153), 'lightslategrey': RGBColor(red=119, green=136, blue=153), 'lightsteelblue': RGBColor(red=176, green=196, blue=222), 'lightsteelblue1': RGBColor(red=202, green=225, blue=255), 'lightsteelblue2': RGBColor(red=188, green=210, blue=238), 'lightsteelblue3': RGBColor(red=162, green=181, blue=205), 'lightsteelblue4': RGBColor(red=110, green=123, blue=139), 'lightyellow': RGBColor(red=255, green=255, blue=224), 'lightyellow1': RGBColor(red=255, green=255, blue=224), 'lightyellow2': RGBColor(red=238, green=238, blue=209), 'lightyellow3': RGBColor(red=205, green=205, blue=180), 'lightyellow4': RGBColor(red=139, green=139, blue=122), 'lime': RGBColor(red=0, green=255, blue=0), 'limegreen': RGBColor(red=50, green=205, blue=50), 'linen': RGBColor(red=250, green=240, blue=230), 'magenta': RGBColor(red=255, green=0, blue=255), 'magenta1': RGBColor(red=255, green=0, blue=255), 'magenta2': RGBColor(red=238, green=0, blue=238), 'magenta3': RGBColor(red=205, green=0, blue=205), 'magenta4': RGBColor(red=139, green=0, blue=139), 'maroon': RGBColor(red=176, green=48, blue=96), 'maroon1': RGBColor(red=255, green=52, blue=179), 'maroon2': RGBColor(red=238, green=48, blue=167), 'maroon3': RGBColor(red=205, green=41, blue=144), 'maroon4': RGBColor(red=139, green=28, blue=98), 'mediumaquamarine': RGBColor(red=102, green=205, blue=170), 'mediumblue': RGBColor(red=0, green=0, blue=205), 'mediumorchid': RGBColor(red=186, green=85, blue=211), 'mediumorchid1': RGBColor(red=224, green=102, blue=255), 'mediumorchid2': RGBColor(red=209, green=95, blue=238), 'mediumorchid3': RGBColor(red=180, green=82, blue=205), 'mediumorchid4': RGBColor(red=122, green=55, blue=139), 'mediumpurple': RGBColor(red=147, green=112, blue=219), 'mediumpurple1': RGBColor(red=171, green=130, blue=255), 'mediumpurple2': RGBColor(red=159, green=121, blue=238), 'mediumpurple3': RGBColor(red=137, green=104, blue=205), 'mediumpurple4': RGBColor(red=93, green=71, blue=139), 'mediumseagreen': RGBColor(red=60, green=179, blue=113), 'mediumslateblue': RGBColor(red=123, green=104, blue=238), 'mediumspringgreen': RGBColor(red=0, green=250, blue=154), 'mediumturquoise': RGBColor(red=72, green=209, blue=204), 'mediumvioletred': RGBColor(red=199, green=21, blue=133), 'midnightblue': RGBColor(red=25, green=25, blue=112), 'mintcream': RGBColor(red=245, green=255, blue=250), 'mistyrose': RGBColor(red=255, green=228, blue=225), 'mistyrose1': RGBColor(red=255, green=228, blue=225), 'mistyrose2': RGBColor(red=238, green=213, blue=210), 'mistyrose3': RGBColor(red=205, green=183, blue=181), 'mistyrose4': RGBColor(red=139, green=125, blue=123), 'moccasin': RGBColor(red=255, green=228, blue=181), 'navajowhite': RGBColor(red=255, green=222, blue=173), 'navajowhite1': RGBColor(red=255, green=222, blue=173), 'navajowhite2': RGBColor(red=238, green=207, blue=161), 'navajowhite3': RGBColor(red=205, green=179, blue=139), 'navajowhite4': RGBColor(red=139, green=121, blue=94), 'navy': RGBColor(red=0, green=0, blue=128), 'navyblue': RGBColor(red=0, green=0, blue=128), 'oldlace': RGBColor(red=253, green=245, blue=230), 'olive': RGBColor(red=128, green=128, blue=0), 'olivedrab': RGBColor(red=107, green=142, blue=35), 'olivedrab1': RGBColor(red=192, green=255, blue=62), 'olivedrab2': RGBColor(red=179, green=238, blue=58), 'olivedrab3': RGBColor(red=154, green=205, blue=50), 'olivedrab4': RGBColor(red=105, green=139, blue=34), 'orange': RGBColor(red=255, green=165, blue=0), 'orange1': RGBColor(red=255, green=165, blue=0), 'orange2': RGBColor(red=238, green=154, blue=0), 'orange3': RGBColor(red=205, green=133, blue=0), 'orange4': RGBColor(red=139, green=90, blue=0), 'orangered': RGBColor(red=255, green=69, blue=0), 'orangered1': RGBColor(red=255, green=69, blue=0), 'orangered2': RGBColor(red=238, green=64, blue=0), 'orangered3': RGBColor(red=205, green=55, blue=0), 'orangered4': RGBColor(red=139, green=37, blue=0), 'orchid': RGBColor(red=218, green=112, blue=214), 'orchid1': RGBColor(red=255, green=131, blue=250), 'orchid2': RGBColor(red=238, green=122, blue=233), 'orchid3': RGBColor(red=205, green=105, blue=201), 'orchid4': RGBColor(red=139, green=71, blue=137), 'palegoldenrod': RGBColor(red=238, green=232, blue=170), 'palegreen': RGBColor(red=152, green=251, blue=152), 'palegreen1': RGBColor(red=154, green=255, blue=154), 'palegreen2': RGBColor(red=144, green=238, blue=144), 'palegreen3': RGBColor(red=124, green=205, blue=124), 'palegreen4': RGBColor(red=84, green=139, blue=84), 'paleturquoise': RGBColor(red=175, green=238, blue=238), 'paleturquoise1': RGBColor(red=187, green=255, blue=255), 'paleturquoise2': RGBColor(red=174, green=238, blue=238), 'paleturquoise3': RGBColor(red=150, green=205, blue=205), 'paleturquoise4': RGBColor(red=102, green=139, blue=139), 'palevioletred': RGBColor(red=219, green=112, blue=147), 'palevioletred1': RGBColor(red=255, green=130, blue=171), 'palevioletred2': RGBColor(red=238, green=121, blue=159), 'palevioletred3': RGBColor(red=205, green=104, blue=137), 'palevioletred4': RGBColor(red=139, green=71, blue=93), 'papayawhip': RGBColor(red=255, green=239, blue=213), 'peachpuff': RGBColor(red=255, green=218, blue=185), 'peachpuff1': RGBColor(red=255, green=218, blue=185), 'peachpuff2': RGBColor(red=238, green=203, blue=173), 'peachpuff3': RGBColor(red=205, green=175, blue=149), 'peachpuff4': RGBColor(red=139, green=119, blue=101), 'peru': RGBColor(red=205, green=133, blue=63), 'pink': RGBColor(red=255, green=192, blue=203), 'pink1': RGBColor(red=255, green=181, blue=197), 'pink2': RGBColor(red=238, green=169, blue=184), 'pink3': RGBColor(red=205, green=145, blue=158), 'pink4': RGBColor(red=139, green=99, blue=108), 'plum': RGBColor(red=221, green=160, blue=221), 'plum1': RGBColor(red=255, green=187, blue=255), 'plum2': RGBColor(red=238, green=174, blue=238), 'plum3': RGBColor(red=205, green=150, blue=205), 'plum4': RGBColor(red=139, green=102, blue=139), 'powderblue': RGBColor(red=176, green=224, blue=230), 'purple': RGBColor(red=160, green=32, blue=240), 'purple1': RGBColor(red=155, green=48, blue=255), 'purple2': RGBColor(red=145, green=44, blue=238), 'purple3': RGBColor(red=125, green=38, blue=205), 'purple4': RGBColor(red=85, green=26, blue=139), 'rebeccapurple': RGBColor(red=102, green=51, blue=153), 'red': RGBColor(red=255, green=0, blue=0), 'red1': RGBColor(red=255, green=0, blue=0), 'red2': RGBColor(red=238, green=0, blue=0), 'red3': RGBColor(red=205, green=0, blue=0), 'red4': RGBColor(red=139, green=0, blue=0), 'rosybrown': RGBColor(red=188, green=143, blue=143), 'rosybrown1': RGBColor(red=255, green=193, blue=193), 'rosybrown2': RGBColor(red=238, green=180, blue=180), 'rosybrown3': RGBColor(red=205, green=155, blue=155), 'rosybrown4': RGBColor(red=139, green=105, blue=105), 'royalblue': RGBColor(red=65, green=105, blue=225), 'royalblue1': RGBColor(red=72, green=118, blue=255), 'royalblue2': RGBColor(red=67, green=110, blue=238), 'royalblue3': RGBColor(red=58, green=95, blue=205), 'royalblue4': RGBColor(red=39, green=64, blue=139), 'saddlebrown': RGBColor(red=139, green=69, blue=19), 'salmon': RGBColor(red=250, green=128, blue=114), 'salmon1': RGBColor(red=255, green=140, blue=105), 'salmon2': RGBColor(red=238, green=130, blue=98), 'salmon3': RGBColor(red=205, green=112, blue=84), 'salmon4': RGBColor(red=139, green=76, blue=57), 'sandybrown': RGBColor(red=244, green=164, blue=96), 'seagreen': RGBColor(red=46, green=139, blue=87), 'seagreen1': RGBColor(red=84, green=255, blue=159), 'seagreen2': RGBColor(red=78, green=238, blue=148), 'seagreen3': RGBColor(red=67, green=205, blue=128), 'seagreen4': RGBColor(red=46, green=139, blue=87), 'seashell': RGBColor(red=255, green=245, blue=238), 'seashell1': RGBColor(red=255, green=245, blue=238), 'seashell2': RGBColor(red=238, green=229, blue=222), 'seashell3': RGBColor(red=205, green=197, blue=191), 'seashell4': RGBColor(red=139, green=134, blue=130), 'sienna': RGBColor(red=160, green=82, blue=45), 'sienna1': RGBColor(red=255, green=130, blue=71), 'sienna2': RGBColor(red=238, green=121, blue=66), 'sienna3': RGBColor(red=205, green=104, blue=57), 'sienna4': RGBColor(red=139, green=71, blue=38), 'silver': RGBColor(red=192, green=192, blue=192), 'skyblue': RGBColor(red=135, green=206, blue=235), 'skyblue1': RGBColor(red=135, green=206, blue=255), 'skyblue2': RGBColor(red=126, green=192, blue=238), 'skyblue3': RGBColor(red=108, green=166, blue=205), 'skyblue4': RGBColor(red=74, green=112, blue=139), 'slateblue': RGBColor(red=106, green=90, blue=205), 'slateblue1': RGBColor(red=131, green=111, blue=255), 'slateblue2': RGBColor(red=122, green=103, blue=238), 'slateblue3': RGBColor(red=105, green=89, blue=205), 'slateblue4': RGBColor(red=71, green=60, blue=139), 'slategray': RGBColor(red=112, green=128, blue=144), 'slategray1': RGBColor(red=198, green=226, blue=255), 'slategray2': RGBColor(red=185, green=211, blue=238), 'slategray3': RGBColor(red=159, green=182, blue=205), 'slategray4': RGBColor(red=108, green=123, blue=139), 'slategrey': RGBColor(red=112, green=128, blue=144), 'snow': RGBColor(red=255, green=250, blue=250), 'snow1': RGBColor(red=255, green=250, blue=250), 'snow2': RGBColor(red=238, green=233, blue=233), 'snow3': RGBColor(red=205, green=201, blue=201), 'snow4': RGBColor(red=139, green=137, blue=137), 'springgreen': RGBColor(red=0, green=255, blue=127), 'springgreen1': RGBColor(red=0, green=255, blue=127), 'springgreen2': RGBColor(red=0, green=238, blue=118), 'springgreen3': RGBColor(red=0, green=205, blue=102), 'springgreen4': RGBColor(red=0, green=139, blue=69), 'steelblue': RGBColor(red=70, green=130, blue=180), 'steelblue1': RGBColor(red=99, green=184, blue=255), 'steelblue2': RGBColor(red=92, green=172, blue=238), 'steelblue3': RGBColor(red=79, green=148, blue=205), 'steelblue4': RGBColor(red=54, green=100, blue=139), 'tan': RGBColor(red=210, green=180, blue=140), 'tan1': RGBColor(red=255, green=165, blue=79), 'tan2': RGBColor(red=238, green=154, blue=73), 'tan3': RGBColor(red=205, green=133, blue=63), 'tan4': RGBColor(red=139, green=90, blue=43), 'teal': RGBColor(red=0, green=128, blue=128), 'thistle': RGBColor(red=216, green=191, blue=216), 'thistle1': RGBColor(red=255, green=225, blue=255), 'thistle2': RGBColor(red=238, green=210, blue=238), 'thistle3': RGBColor(red=205, green=181, blue=205), 'thistle4': RGBColor(red=139, green=123, blue=139), 'tomato': RGBColor(red=255, green=99, blue=71), 'tomato1': RGBColor(red=255, green=99, blue=71), 'tomato2': RGBColor(red=238, green=92, blue=66), 'tomato3': RGBColor(red=205, green=79, blue=57), 'tomato4': RGBColor(red=139, green=54, blue=38), 'turquoise': RGBColor(red=64, green=224, blue=208), 'turquoise1': RGBColor(red=0, green=245, blue=255), 'turquoise2': RGBColor(red=0, green=229, blue=238), 'turquoise3': RGBColor(red=0, green=197, blue=205), 'turquoise4': RGBColor(red=0, green=134, blue=139), 'violet': RGBColor(red=238, green=130, blue=238), 'violetred': RGBColor(red=208, green=32, blue=144), 'violetred1': RGBColor(red=255, green=62, blue=150), 'violetred2': RGBColor(red=238, green=58, blue=140), 'violetred3': RGBColor(red=205, green=50, blue=120), 'violetred4': RGBColor(red=139, green=34, blue=82), 'webgray': RGBColor(red=128, green=128, blue=128), 'webgreen': RGBColor(red=0, green=128, blue=0), 'webgrey': RGBColor(red=128, green=128, blue=128), 'webmaroon': RGBColor(red=128, green=0, blue=0), 'webpurple': RGBColor(red=128, green=0, blue=128), 'wheat': RGBColor(red=245, green=222, blue=179), 'wheat1': RGBColor(red=255, green=231, blue=186), 'wheat2': RGBColor(red=238, green=216, blue=174), 'wheat3': RGBColor(red=205, green=186, blue=150), 'wheat4': RGBColor(red=139, green=126, blue=102), 'white': RGBColor(red=255, green=255, blue=255), 'whitesmoke': RGBColor(red=245, green=245, blue=245), 'x11gray': RGBColor(red=190, green=190, blue=190), 'x11green': RGBColor(red=0, green=255, blue=0), 'x11grey': RGBColor(red=190, green=190, blue=190), 'x11maroon': RGBColor(red=176, green=48, blue=96), 'x11purple': RGBColor(red=160, green=32, blue=240), 'yellow': RGBColor(red=255, green=255, blue=0), 'yellow1': RGBColor(red=255, green=255, blue=0), 'yellow2': RGBColor(red=238, green=238, blue=0), 'yellow3': RGBColor(red=205, green=205, blue=0), 'yellow4': RGBColor(red=139, green=139, blue=0), 'yellowgreen': RGBColor(red=154, green=205, blue=50)}

  X11 Color names to (XTerm-defined) RGB values from xorg-rgb/rgb.txt

`RGB_256TABLE` = (RGBColor(red=0, green=0, blue=0), RGBColor(red=205, green=0, blue=0), RGBColor(red=0, green=205, blue=0), RGBColor(red=205, green=205, blue=0), RGBColor(red=0, green=0, blue=238), RGBColor(red=205, green=0, blue=205), RGBColor(red=0, green=205, blue=205), RGBColor(red=229, green=229, blue=229), RGBColor(red=127, green=127, blue=127), RGBColor(red=255, green=0, blue=0), RGBColor(red=0, green=255, blue=0), RGBColor(red=255, green=255, blue=0), RGBColor(red=92, green=92, blue=255), RGBColor(red=255, green=0, blue=255), RGBColor(red=0, green=255, blue=255), RGBColor(red=255, green=255, blue=255), RGBColor(red=0, green=0, blue=0), RGBColor(red=0, green=0, blue=95), RGBColor(red=0, green=0, blue=135), RGBColor(red=0, green=0, blue=175), RGBColor(red=0, green=0, blue=215), RGBColor(red=0, green=0, blue=255), RGBColor(red=0, green=95, blue=0), RGBColor(red=0, green=95, blue=95), RGBColor(red=0, green=95, blue=135), RGBColor(red=0, green=95, blue=175), RGBColor(red=0, green=95, blue=215), RGBColor(red=0, green=95, blue=255), RGBColor(red=0, green=135, blue=0), RGBColor(red=0, green=135, blue=95), RGBColor(red=0, green=135, blue=135), RGBColor(red=0, green=135, blue=175), RGBColor(red=0, green=135, blue=215), RGBColor(red=0, green=135, blue=255), RGBColor(red=0, green=175, blue=0), RGBColor(red=0, green=175, blue=95), RGBColor(red=0, green=175, blue=135), RGBColor(red=0, green=175, blue=175), RGBColor(red=0, green=175, blue=215), RGBColor(red=0, green=175, blue=255), RGBColor(red=0, green=215, blue=0), RGBColor(red=0, green=215, blue=95), RGBColor(red=0, green=215, blue=135), RGBColor(red=0, green=215, blue=175), RGBColor(red=0, green=215, blue=215), RGBColor(red=0, green=215, blue=255), RGBColor(red=0, green=255, blue=0), RGBColor(red=0, green=255, blue=95), RGBColor(red=0, green=255, blue=135), RGBColor(red=0, green=255, blue=175), RGBColor(red=0, green=255, blue=215), RGBColor(red=0, green=255, blue=255), RGBColor(red=95, green=0, blue=0), RGBColor(red=95, green=0, blue=95), RGBColor(red=95, green=0, blue=135), RGBColor(red=95, green=0, blue=175), RGBColor(red=95, green=0, blue=215), RGBColor(red=95, green=0, blue=255), RGBColor(red=95, green=95, blue=0), RGBColor(red=95, green=95, blue=95), RGBColor(red=95, green=95, blue=135), RGBColor(red=95, green=95, blue=175), RGBColor(red=95, green=95, blue=215), RGBColor(red=95, green=95, blue=255), RGBColor(red=95, green=135, blue=0), RGBColor(red=95, green=135, blue=95), RGBColor(red=95, green=135, blue=135), RGBColor(red=95, green=135, blue=175), RGBColor(red=95, green=135, blue=215), RGBColor(red=95, green=135, blue=255), RGBColor(red=95, green=175, blue=0), RGBColor(red=95, green=175, blue=95), RGBColor(red=95, green=175, blue=135), RGBColor(red=95, green=175, blue=175), RGBColor(red=95, green=175, blue=215), RGBColor(red=95, green=175, blue=255), RGBColor(red=95, green=215, blue=0), RGBColor(red=95, green=215, blue=95), RGBColor(red=95, green=215, blue=135), RGBColor(red=95, green=215, blue=175), RGBColor(red=95, green=215, blue=215), RGBColor(red=95, green=215, blue=255), RGBColor(red=95, green=255, blue=0), RGBColor(red=95, green=255, blue=95), RGBColor(red=95, green=255, blue=135), RGBColor(red=95, green=255, blue=175), RGBColor(red=95, green=255, blue=215), RGBColor(red=95, green=255, blue=255), RGBColor(red=135, green=0, blue=0), RGBColor(red=135, green=0, blue=95), RGBColor(red=135, green=0, blue=135), RGBColor(red=135, green=0, blue=175), RGBColor(red=135, green=0, blue=215), RGBColor(red=135, green=0, blue=255), RGBColor(red=135, green=95, blue=0), RGBColor(red=135, green=95, blue=95), RGBColor(red=135, green=95, blue=135), RGBColor(red=135, green=95, blue=175), RGBColor(red=135, green=95, blue=215), RGBColor(red=135, green=95, blue=255), RGBColor(red=135, green=135, blue=0), RGBColor(red=135, green=135, blue=95), RGBColor(red=135, green=135, blue=135), RGBColor(red=135, green=135, blue=175), RGBColor(red=135, green=135, blue=215), RGBColor(red=135, green=135, blue=255), RGBColor(red=135, green=175, blue=0), RGBColor(red=135, green=175, blue=95), RGBColor(red=135, green=175, blue=135), RGBColor(red=135, green=175, blue=175), RGBColor(red=135, green=175, blue=215), RGBColor(red=135, green=175, blue=255), RGBColor(red=135, green=215, blue=0), RGBColor(red=135, green=215, blue=95), RGBColor(red=135, green=215, blue=135), RGBColor(red=135, green=215, blue=175), RGBColor(red=135, green=215, blue=215), RGBColor(red=135, green=215, blue=255), RGBColor(red=135, green=255, blue=0), RGBColor(red=135, green=255, blue=95), RGBColor(red=135, green=255, blue=135), RGBColor(red=135, green=255, blue=175), RGBColor(red=135, green=255, blue=215), RGBColor(red=135, green=255, blue=255), RGBColor(red=175, green=0, blue=0), RGBColor(red=175, green=0, blue=95), RGBColor(red=175, green=0, blue=135), RGBColor(red=175, green=0, blue=175), RGBColor(red=175, green=0, blue=215), RGBColor(red=175, green=0, blue=255), RGBColor(red=175, green=95, blue=0), RGBColor(red=175, green=95, blue=95), RGBColor(red=175, green=95, blue=135), RGBColor(red=175, green=95, blue=175), RGBColor(red=175, green=95, blue=215), RGBColor(red=175, green=95, blue=255), RGBColor(red=175, green=135, blue=0), RGBColor(red=175, green=135, blue=95), RGBColor(red=175, green=135, blue=135), RGBColor(red=175, green=135, blue=175), RGBColor(red=175, green=135, blue=215), RGBColor(red=175, green=135, blue=255), RGBColor(red=175, green=175, blue=0), RGBColor(red=175, green=175, blue=95), RGBColor(red=175, green=175, blue=135), RGBColor(red=175, green=175, blue=175), RGBColor(red=175, green=175, blue=215), RGBColor(red=175, green=175, blue=255), RGBColor(red=175, green=215, blue=0), RGBColor(red=175, green=215, blue=95), RGBColor(red=175, green=215, blue=135), RGBColor(red=175, green=215, blue=175), RGBColor(red=175, green=215, blue=215), RGBColor(red=175, green=215, blue=255), RGBColor(red=175, green=255, blue=0), RGBColor(red=175, green=255, blue=95), RGBColor(red=175, green=255, blue=135), RGBColor(red=175, green=255, blue=175), RGBColor(red=175, green=255, blue=215), RGBColor(red=175, green=255, blue=255), RGBColor(red=215, green=0, blue=0), RGBColor(red=215, green=0, blue=95), RGBColor(red=215, green=0, blue=135), RGBColor(red=215, green=0, blue=175), RGBColor(red=215, green=0, blue=215), RGBColor(red=215, green=0, blue=255), RGBColor(red=215, green=95, blue=0), RGBColor(red=215, green=95, blue=95), RGBColor(red=215, green=95, blue=135), RGBColor(red=215, green=95, blue=175), RGBColor(red=215, green=95, blue=215), RGBColor(red=215, green=95, blue=255), RGBColor(red=215, green=135, blue=0), RGBColor(red=215, green=135, blue=95), RGBColor(red=215, green=135, blue=135), RGBColor(red=215, green=135, blue=175), RGBColor(red=215, green=135, blue=215), RGBColor(red=215, green=135, blue=255), RGBColor(red=215, green=175, blue=0), RGBColor(red=215, green=175, blue=95), RGBColor(red=215, green=175, blue=135), RGBColor(red=215, green=175, blue=175), RGBColor(red=215, green=175, blue=215), RGBColor(red=215, green=175, blue=255), RGBColor(red=215, green=215, blue=0), RGBColor(red=215, green=215, blue=95), RGBColor(red=215, green=215, blue=135), RGBColor(red=215, green=215, blue=175), RGBColor(red=215, green=215, blue=215), RGBColor(red=215, green=215, blue=255), RGBColor(red=215, green=255, blue=0), RGBColor(red=215, green=255, blue=95), RGBColor(red=215, green=255, blue=135), RGBColor(red=215, green=255, blue=175), RGBColor(red=215, green=255, blue=215), RGBColor(red=215, green=255, blue=255), RGBColor(red=255, green=0, blue=0), RGBColor(red=255, green=0, blue=135), RGBColor(red=255, green=0, blue=95), RGBColor(red=255, green=0, blue=175), RGBColor(red=255, green=0, blue=215), RGBColor(red=255, green=0, blue=255), RGBColor(red=255, green=95, blue=0), RGBColor(red=255, green=95, blue=95), RGBColor(red=255, green=95, blue=135), RGBColor(red=255, green=95, blue=175), RGBColor(red=255, green=95, blue=215), RGBColor(red=255, green=95, blue=255), RGBColor(red=255, green=135, blue=0), RGBColor(red=255, green=135, blue=95), RGBColor(red=255, green=135, blue=135), RGBColor(red=255, green=135, blue=175), RGBColor(red=255, green=135, blue=215), RGBColor(red=255, green=135, blue=255), RGBColor(red=255, green=175, blue=0), RGBColor(red=255, green=175, blue=95), RGBColor(red=255, green=175, blue=135), RGBColor(red=255, green=175, blue=175), RGBColor(red=255, green=175, blue=215), RGBColor(red=255, green=175, blue=255), RGBColor(red=255, green=215, blue=0), RGBColor(red=255, green=215, blue=95), RGBColor(red=255, green=215, blue=135), RGBColor(red=255, green=215, blue=175), RGBColor(red=255, green=215, blue=215), RGBColor(red=255, green=215, blue=255), RGBColor(red=255, green=255, blue=0), RGBColor(red=255, green=255, blue=95), RGBColor(red=255, green=255, blue=135), RGBColor(red=255, green=255, blue=175), RGBColor(red=255, green=255, blue=215), RGBColor(red=255, green=255, blue=255), RGBColor(red=8, green=8, blue=8), RGBColor(red=18, green=18, blue=18), RGBColor(red=28, green=28, blue=28), RGBColor(red=38, green=38, blue=38), RGBColor(red=48, green=48, blue=48), RGBColor(red=58, green=58, blue=58), RGBColor(red=68, green=68, blue=68), RGBColor(red=78, green=78, blue=78), RGBColor(red=88, green=88, blue=88), RGBColor(red=98, green=98, blue=98), RGBColor(red=108, green=108, blue=108), RGBColor(red=118, green=118, blue=118), RGBColor(red=128, green=128, blue=128), RGBColor(red=138, green=138, blue=138), RGBColor(red=148, green=148, blue=148), RGBColor(red=158, green=158, blue=158), RGBColor(red=168, green=168, blue=168), RGBColor(red=178, green=178, blue=178), RGBColor(red=188, green=188, blue=188), RGBColor(red=198, green=198, blue=198), RGBColor(red=208, green=208, blue=208), RGBColor(red=218, green=218, blue=218), RGBColor(red=228, green=228, blue=228), RGBColor(red=238, green=238, blue=238))

  Curses color indices of 8, 16, and 256-color terminals